@@ -2,6 +2,36 @@ from . import *
 
 
 class CookBookUi:
+	def list_uids_names(self):
+		while True:
+			try:
+				with Session(ENGINE) as session:
+					stext=Prompt.__init2__(None,func=FormBuilderMkText,ptext="Name or UID?[b=skip]",helpText="b|back skips",data="string")
+					if stext is None:
+						return None,None
+					if stext in ['d',]:
+						query=session.query(CookBook)
+					else:
+						query=session.query(CookBook).filter(or_(CookBook.recipe_uid.icontains(stext),CookBook.recipe_name.icontains(stext)))	
+					
+					query=query.group_by(CookBook.recipe_uid,CookBook.recipe_name)
+					query=orderQuery(query,CookBook.DTOE,inverse=True)
+					results=query.all()
+					ct=len(results)
+					htext=[]
+					for num,i in enumerate(results):
+						htext.append(std_colorize(f"'{i.recipe_name}' [Name] - '{i.recipe_uid}' [UID] - '{i.cbid}' [cbid]",num,ct))
+					htext='\n'.join(htext)
+					print(htext)
+					which=Prompt.__init2__(None,func=FormBuilderMkText,ptext="which index to use?",helpText=htext,data="integer")
+					if which is None:
+						return None,None
+					elif which in ['d',]:
+						which=0
+					return results[which].recipe_uid,results[which].recipe_name
+			except Exception as e:
+				print(e)
+
 	def total_rcp(self):
 		with Session(ENGINE) as session:
 			rcp=self.ls_rcp_names(asSelector=True,whole=True,names=True)
@@ -65,6 +95,7 @@ class CookBookUi:
 		#edit everything found by searchtext using recipe_uid as the final selection parameter
 	def create_new_rcp(self):
 		with Session(ENGINE) as session:
+			ruid,rname=self.list_uids_names()
 			uid=uuid1()
 			uid=str(uid)
 			excludes=['cbid','DTOE','recipe_uid','Instructions','recipe_name']
@@ -163,8 +194,14 @@ class CookBookUi:
 					return
 			instructions={
 			'Instructions':{'default':'','type':'text'},
-			'recipe_name':{'default':'','type':'string'}}
+			'recipe_name':{'default':'','type':'string'},
+			'recipe_uid':{'default':'','type':'string'}}
+			if rname is not None:
+				instructions['recipe_name']['default']=rname
+			if ruid is not None:
+				instructions['recipe_uid']['default']=ruid
 			fdi=FormBuilder(data=instructions)
+			
 			if fdi is None:
 				print("User Quit Early, so all work has been deleted!")
 				r=session.query(CookBook).filter(CookBook.recipe_uid==uid).delete()
