@@ -276,6 +276,8 @@ class HealthLogUi:
 							dfTmp['DTOES']=dfTmp['DTOE'].dt.strftime("%d/%m/%Y")
 							z=[[v,u] for v,u in zip(dfTmp[field],dfTmp['DrugQtyConsumedUnitName'])]
 							units=[i for i in dfTmp['DrugQtyConsumedUnitName'].unique()]
+							
+
 							for i in z:
 								print(pint.Quantity(i[0],i[1]).magnitude,i[-1])
 							unit=''
@@ -323,6 +325,22 @@ class HealthLogUi:
 							except Exception as e:
 								if errors:
 									print(e)
+
+							try:
+								df_from_records['tsa']=pd.to_datetime(df_from_records['DTOE'])
+								times_recorded=[int(f"{i.hour}") for i in df_from_records['tsa']]
+								bins=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"Histogram Bins[bins for 24H]",helpText=f"bins for 24H",data="integer")
+								if bins is None:
+									return
+								elif bins in ['d',]:
+									bins=24
+								plt.hist(times_recorded,bins=bins,label=histoLabel)
+								plt.show()
+								plt.clf()
+								print(f"{Fore.orange_red_1}Hours of the Day Recorded{Fore.magenta}{histoLabel}total Entry Data Points = {len(dfTmp[field])}{Style.reset}")
+							except Exception as e:
+								if errors:
+									print(e,'#ec2')
 					
 					barLabel=f'Maxes {field} TotalView:Bar'
 					
@@ -368,6 +386,22 @@ class HealthLogUi:
 					except Exception as e:
 						if errors:
 							print(e)
+
+					try:
+						df_from_records['tsa']=pd.to_datetime(df_from_records['DTOE'])
+						times_recorded=[int(f"{i.hour}") for i in df_from_records['tsa']]
+						bins=Prompt.__init2__(None,func=FormBuilderMkText,ptext=f"Histogram Bins[bins for 24H]",helpText=f"bins for 24H",data="integer")
+						if bins is None:
+							return
+						elif bins in ['d',]:
+							bins=24
+						plt.hist(times_recorded,bins=bins,label=histoLabel)
+						plt.show()
+						plt.clf()
+						print(f"{Fore.orange_red_1}Hours of the Day Recorded{Fore.magenta}{histoLabel}total Entry Data Points = {len(df_from_records[field])}{Style.reset}")
+					except Exception as e:
+						if errors:
+							print(e,'ec3')
 				except Exception as ee:
 					if errors:
 						print(ee,repr(ee))
